"""Mock YouTube search data for development without API quota usage."""

# Sample search results that mimic real YouTube API responses
MOCK_SEARCH_RESULTS = [
    {
        "video_id": "mock_abcdef123",
        "title": "ABBA - Dancing Queen (Official Music Video)",
        "channel": "ABBA",
        "thumbnail_url": "https://i.ytimg.com/vi/xFrGuyw1V8s/hqdefault.jpg",
        "description": "The official music video for Dancing Queen by ABBA",
    },
    {
        "video_id": "mock_xyz789def",
        "title": "The Beatles - Here Comes The Sun",
        "channel": "The Beatles",
        "thumbnail_url": "https://i.ytimg.com/vi/KQetemT1sWc/hqdefault.jpg",
        "description": "The Beatles performing Here Comes The Sun",
    },
    {
        "video_id": "mock_qwe456rty",
        "title": "Queen - Bohemian Rhapsody (Official Video)",
        "channel": "Queen Official",
        "thumbnail_url": "https://i.ytimg.com/vi/fJ9rUzIMcZQ/hqdefault.jpg",
        "description": "Bohemian Rhapsody by Queen",
    },
    {
        "video_id": "mock_asd789fgh",
        "title": "Michael Jackson - Billie Jean (Official Video)",
        "channel": "Michael Jackson",
        "thumbnail_url": "https://i.ytimg.com/vi/Zi_XLOBDo_Y/hqdefault.jpg",
        "description": "The official video for Billie Jean by Michael Jackson",
    },
    {
        "video_id": "mock_zxc123vbn",
        "title": "Fleetwood Mac - Dreams (Official Music Video)",
        "channel": "Fleetwood Mac",
        "thumbnail_url": "https://i.ytimg.com/vi/mrZRURcb1cM/hqdefault.jpg",
        "description": "Dreams by Fleetwood Mac",
    },
    {
        "video_id": "mock_poi098lkj",
        "title": "David Bowie - Space Oddity",
        "channel": "David Bowie",
        "thumbnail_url": "https://i.ytimg.com/vi/iYYRH4apXDo/hqdefault.jpg",
        "description": "Space Oddity by David Bowie",
    },
    {
        "video_id": "mock_mnb567vcx",
        "title": "The Rolling Stones - Paint It Black (Official Lyric Video)",
        "channel": "The Rolling Stones",
        "thumbnail_url": "https://i.ytimg.com/vi/O4irXQhgMqg/hqdefault.jpg",
        "description": "Paint It Black by The Rolling Stones",
    },
    {
        "video_id": "mock_jkl234mno",
        "title": "Pink Floyd - Another Brick in the Wall",
        "channel": "Pink Floyd",
        "thumbnail_url": "https://i.ytimg.com/vi/YR5ApYxkU-U/hqdefault.jpg",
        "description": "Another Brick in the Wall by Pink Floyd",
    },
    {
        "video_id": "mock_ghi890pqr",
        "title": "Elton John - Rocket Man (Official Music Video)",
        "channel": "Elton John",
        "thumbnail_url": "https://i.ytimg.com/vi/DtVBCG6ThDk/hqdefault.jpg",
        "description": "Rocket Man by Elton John",
    },
    {
        "video_id": "mock_stu345wxy",
        "title": "Led Zeppelin - Stairway to Heaven",
        "channel": "Led Zeppelin",
        "thumbnail_url": "https://i.ytimg.com/vi/QkF3oxziUI4/hqdefault.jpg",
        "description": "Stairway to Heaven by Led Zeppelin",
    },
    {
        "video_id": "mock_def678abc",
        "title": "Eagles - Hotel California (Live)",
        "channel": "Eagles",
        "thumbnail_url": "https://i.ytimg.com/vi/09839DpTctU/hqdefault.jpg",
        "description": "Hotel California live performance by Eagles",
    },
    {
        "video_id": "mock_vwx901yza",
        "title": "Bee Gees - Stayin' Alive (Official Music Video)",
        "channel": "Bee Gees",
        "thumbnail_url": "https://i.ytimg.com/vi/fNFzfwLM72c/hqdefault.jpg",
        "description": "Stayin' Alive by Bee Gees",
    },
    {
        "video_id": "mock_bcd234efg",
        "title": "Simon & Garfunkel - The Sound of Silence",
        "channel": "Simon & Garfunkel",
        "thumbnail_url": "https://i.ytimg.com/vi/4fWyzwo1xg0/hqdefault.jpg",
        "description": "The Sound of Silence by Simon & Garfunkel",
    },
    {
        "video_id": "mock_hij567klm",
        "title": "Bob Dylan - Like a Rolling Stone",
        "channel": "Bob Dylan",
        "thumbnail_url": "https://i.ytimg.com/vi/IwOfCgkyEj0/hqdefault.jpg",
        "description": "Like a Rolling Stone by Bob Dylan",
    },
    {
        "video_id": "mock_nop890qrs",
        "title": "Stevie Wonder - Superstition (Official Video)",
        "channel": "Stevie Wonder",
        "thumbnail_url": "https://i.ytimg.com/vi/0CFuCYNx-1g/hqdefault.jpg",
        "description": "Superstition by Stevie Wonder",
    },
]
